##  Deactivating the API
You can deactivate the AI Agent API if needed. This action stops uploads of AI agent cards through the API. Previously uploaded data remains unaffected.
To deactivate the AI Agent API, follow these steps:
  1. Go to the Integrations section in the administration area.
  2. On the Integrations page, choose AI Agent API.
  3. On the AI Agent API page, choose the three-dot icon > Disable, then confirm your action.


YesNo
Send
